@@ -12,22 +12,16 @@
 // UNSUPPORTED: nvrtc
 // XFAIL: nvcc
 
-#include "annotated_ptr.h"
+#include "utils.h"
 
-__device__ __host__ __noinline__
-static void negative_test_access_property_functions() {
-    size_t ARR_SZ = 1 << 20;
-    int* arr1 = nullptr;
-    cuda::access_property ap(cuda::access_property::persisting{});
-
-    arr1 = (int*)malloc(ARR_SZ * sizeof(int));
-
-    //calling from host needs to fail and kill the app
-    __nv_associate_access_property(arr1, static_cast<uint64_t>(ap));
+__device__ __host__
+static void fails_from_host() {
+    int a;
+    __nv_associate_access_property(&a, uint64_t{0});
 }
 
 int main(int argc, char ** argv) {
-    negative_test_access_property_functions();
-
+    //calling from host needs to fail and kill the app
+    fails_from_host();
     return 0;
 }
